@@ -37,8 +37,8 @@ class StreamChatAsync(StreamChatInterface):
     async def _parse_response(self, response):
         text = await response.text()
         try:
-            parsed_result = json.loads(text) if text else {}
-        except ValueError:
+            parsed_result = await response.json() if text else {}
+        except aiohttp.ClientResponseError:
             raise StreamAPIException(text, response.status)
         if response.status >= 399:
             raise StreamAPIException(text, response.status)
@@ -107,6 +107,11 @@ class StreamChatAsync(StreamChatInterface):
     async def delete_user(self, user_id, **options):
         return await self.delete(f"users/{user_id}", options)
 
+    async def delete_users(self, user_ids, delete_type, **options):
+        return await self.post(
+            "users/delete", data=dict(options, user=delete_type, user_ids=user_ids)
+        )
+
     async def deactivate_user(self, user_id, **options):
         return await self.post(f"users/{user_id}/deactivate", data=options)
 
@@ -120,6 +125,12 @@ class StreamChatAsync(StreamChatInterface):
         data = {"target_user_id": target_id, **options}
         return await self.post("moderation/ban", data=data)
 
+    async def shadow_ban(self, target_id, **options):
+        return await self.ban_user(target_id, shadow=True, **options)
+
+    async def remove_shadow_ban(self, target_id, **options):
+        return await self.unban_user(target_id, shadow=True, **options)
+
     async def unban_user(self, target_id, **options):
         params = {"target_user_id": target_id, **options}
         return await self.delete("moderation/ban", params)
@@ -236,6 +247,9 @@ class StreamChatAsync(StreamChatInterface):
         """
         return Channel(self, channel_type, channel_id, data)
 
+    async def delete_channels(self, cids, **options):
+        return await self.post("channels/delete", data=dict(options, cids=cids))
+
     async def list_commands(self):
         return await self.get("commands")
 
@@ -650,3 +664,6 @@ class StreamChatAsync(StreamChatInterface):
         exc_tb: Optional[TracebackType],
     ) -> None:
         await self.close()
+
+    async def get_task(self, task_id):
+        return await self.get(f"tasks/{task_id}")
