@@ -96,6 +96,18 @@ class StreamChatInterface(abc.ABC):
     def delete_user(self, user_id, **options):
         pass
 
+    @abc.abstractmethod
+    def delete_users(self, user_ids, delete_type, **options):
+        """
+        Delete users asynchronously
+
+        :param user_ids: a list of user IDs to delete
+        :param delete_type: type of user delete (hard|soft)
+        :param options: additional delete options
+        :return: task_id
+        """
+        pass
+
     @abc.abstractmethod
     def deactivate_user(self, user_id, **options):
         pass
@@ -112,6 +124,14 @@ class StreamChatInterface(abc.ABC):
     def ban_user(self, target_id, **options):
         pass
 
+    @abc.abstractmethod
+    def shadow_ban(self, target_id, **options):
+        pass
+
+    @abc.abstractmethod
+    def remove_shadow_ban(self, target_id, **options):
+        pass
+
     @abc.abstractmethod
     def unban_user(self, target_id, **options):
         pass
@@ -222,6 +242,10 @@ class StreamChatInterface(abc.ABC):
         """
         pass
 
+    @abc.abstractmethod
+    def delete_channels(self, cids, **options):
+        pass
+
     @abc.abstractmethod
     def list_commands(self):
         pass
@@ -570,3 +594,10 @@ class StreamChatInterface(abc.ABC):
         Retrieves status of export
         """
         pass
+
+    @abc.abstractmethod
+    def get_task(self, task_id):
+        """
+        Retrieves status of task
+        """
+        pass
