@@ -150,6 +150,24 @@ class TestClient(object):
         assert "user" in response
         assert random_user["id"] == response["user"]["id"]
 
+    @pytest.mark.asyncio
+    async def test_delete_users(self, event_loop, client, random_user):
+        response = await client.delete_users(
+            [random_user["id"]], "hard", conversations="hard", messages="hard"
+        )
+        assert "task_id" in response
+
+        for _ in range(10):
+            response = await client.get_task(response["task_id"])
+            if response["status"] == "completed" and response["result"][
+                random_user["id"]
+            ] == {"status": "ok"}:
+                return
+
+            time.sleep(1)
+
+        assert False, "task did not succeed"
+
     @pytest.mark.asyncio
     async def test_deactivate_user(self, event_loop, client, random_user):
         response = await client.deactivate_user(random_user["id"])
@@ -175,6 +193,40 @@ class TestClient(object):
     async def test_ban_user(self, event_loop, client, random_user, server_user):
         await client.ban_user(random_user["id"], user_id=server_user["id"])
 
+    @pytest.mark.asyncio
+    async def test_shadow_ban(
+        self, event_loop, client, random_user, server_user, channel
+    ):
+        msg_id = str(uuid.uuid4())
+        response = await channel.send_message(
+            {"id": msg_id, "text": "hello world"}, random_user["id"]
+        )
+
+        response = await client.get_message(msg_id)
+        assert not response["message"]["shadowed"]
+
+        response = await client.shadow_ban(random_user["id"], user_id=server_user["id"])
+
+        msg_id = str(uuid.uuid4())
+        response = await channel.send_message(
+            {"id": msg_id, "text": "hello world"}, random_user["id"]
+        )
+
+        response = await client.get_message(msg_id)
+        assert response["message"]["shadowed"]
+
+        response = await client.remove_shadow_ban(
+            random_user["id"], user_id=server_user["id"]
+        )
+
+        msg_id = str(uuid.uuid4())
+        response = await channel.send_message(
+            {"id": msg_id, "text": "hello world"}, random_user["id"]
+        )
+
+        response = await client.get_message(msg_id)
+        assert not response["message"]["shadowed"]
+
     @pytest.mark.asyncio
     async def test_unban_user(self, event_loop, client, random_user, server_user):
         await client.ban_user(random_user["id"], user_id=server_user["id"])
@@ -468,6 +520,9 @@ class TestClient(object):
             "action": "DeleteChannel",
             "owner": False,
             "same_team": True,
+            "condition": {
+                "$subject.magic_custom_field": "magic_custom_value",
+            },
         }
 
         await client.create_permission(custom)
@@ -504,3 +559,19 @@ class TestClient(object):
         wait()
         response = await client.list_roles()
         assert role not in response["roles"]
+
+    @pytest.mark.asyncio
+    async def test_delete_channels(self, event_loop, client, channel):
+        response = await client.delete_channels([channel.cid])
+        assert "task_id" in response
+
+        for _ in range(10):
+            response = await client.get_task(response["task_id"])
+            if response["status"] == "completed" and response["result"][
+                channel.cid
+            ] == {"status": "ok"}:
+                return
+
+            time.sleep(1)
+
+        assert False, "task did not succeed"
