@@ -129,6 +129,23 @@ class TestClient(object):
         assert "user" in response
         assert random_user["id"] == response["user"]["id"]
 
+    def test_delete_users(self, client, random_user):
+        response = client.delete_users(
+            [random_user["id"]], "hard", conversations="hard", messages="hard"
+        )
+        assert "task_id" in response
+
+        for _ in range(10):
+            response = client.get_task(response["task_id"])
+            if response["status"] == "completed" and response["result"][
+                random_user["id"]
+            ] == {"status": "ok"}:
+                return
+
+            time.sleep(1)
+
+        assert False, "task did not succeed"
+
     def test_deactivate_user(self, client, random_user):
         response = client.deactivate_user(random_user["id"])
         assert "user" in response
@@ -147,6 +164,37 @@ class TestClient(object):
         assert "user" in response
         assert response["user"]["name"] == "Gandalf the Grey"
 
+    def test_shadow_ban(self, client, random_user, server_user, channel):
+        msg_id = str(uuid.uuid4())
+        response = channel.send_message(
+            {"id": msg_id, "text": "hello world"}, random_user["id"]
+        )
+
+        response = client.get_message(msg_id)
+        assert not response["message"]["shadowed"]
+
+        response = client.shadow_ban(random_user["id"], user_id=server_user["id"])
+
+        msg_id = str(uuid.uuid4())
+        response = channel.send_message(
+            {"id": msg_id, "text": "hello world"}, random_user["id"]
+        )
+
+        response = client.get_message(msg_id)
+        assert response["message"]["shadowed"]
+
+        response = client.remove_shadow_ban(
+            random_user["id"], user_id=server_user["id"]
+        )
+
+        msg_id = str(uuid.uuid4())
+        response = channel.send_message(
+            {"id": msg_id, "text": "hello world"}, random_user["id"]
+        )
+
+        response = client.get_message(msg_id)
+        assert not response["message"]["shadowed"]
+
     def test_ban_user(self, client, random_user, server_user):
         client.ban_user(random_user["id"], user_id=server_user["id"])
 
@@ -394,6 +442,9 @@ class TestClient(object):
             "action": "DeleteChannel",
             "owner": False,
             "same_team": True,
+            "condition": {
+                "$subject.magic_custom_field": "magic_custom_value",
+            },
         }
 
         client.create_permission(custom)
@@ -430,3 +481,18 @@ class TestClient(object):
         wait()
         response = client.list_roles()
         assert role not in response["roles"]
+
+    def test_delete_channels(self, client, channel):
+        response = client.delete_channels([channel.cid])
+        assert "task_id" in response
+
+        for _ in range(10):
+            response = client.get_task(response["task_id"])
+            if response["status"] == "completed" and response["result"][
+                channel.cid
+            ] == {"status": "ok"}:
+                return
+
+            time.sleep(1)
+
+        assert False, "task did not succeed"
